# -*- encoding: utf-8 -*-
# (C) Copyright 2008 Tarek Ziadé <tarek@ziade.org>
#
from afpy.xap.indexer import index_document


class Indexer(object):  
    """Indexes the content in a Xapian database"""

    def __call__(self, entry, entries, db=None):
        # todo
        docid = entry['link']
        text = '%s %s' % (entry['title'], entry['summary'])
        index_document(docid, text)
        return entry




import time

from atomisator.indexer import Indexer
from afpy.xap.xapindexer import start_server, stop_server
from afpy.xap.searcher import search 

def test_index():

    i = Indexer()

    entry = {'link': 'http://here',
             'summary': 'index me'}
    i(entry, [])

    # ok so now we should have something
    # to index
    start_server()
    time.sleep(0.5)
    stop_server()

    # let's check 
    assert list(search('index')) == ['http://here']




# -*- encoding: utf-8 -*-                                                      
# (C) Copyright 2008 Tarek Ziadé <tarek@ziade.org>                             
# 
from setuptools import setup, find_packages
import os
from os.path import join
from distutils.core import Extension 

version = '0.1.0'

long_description = open("README.txt").read()

classifiers=[
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: Python Software Foundation License",

        ]

entry_points = {"atomisator.filters": ["indexer = atomisator.indexer:Indexer"]}

setup(name='atomisator.indexer',
      version=version,
      description="Atomisator - Indexing",
      long_description=long_description,
      classifiers=classifiers,
      keywords='atomisator indexer xapian',
      author='Tarek Ziade',
      author_email='tarek@ziade.org',
      url='http://atomisator.ziade.org',
      license='Python',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['atomisator'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'afpy.xap',
      ],
      entry_points=entry_points,
      )

